package com.ruoyi.buyerapi.mapper;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerDeptEmployee;

/**
 * 企业信息员工Mapper接口
 * 
 * @author ruoyi
 * @date 2022-09-22
 */
public interface BuyerDeptEmployeeMapper 
{
    /**
     * 查询企业信息员工
     * 
     * @param id 企业信息员工主键
     * @return 企业信息员工
     */
    public BuyerDeptEmployee selectBuyerDeptEmployeeById(String id);

    /**
     * 查询企业信息员工列表
     * 
     * @param buyerDeptEmployee 企业信息员工
     * @return 企业信息员工集合
     */
    public List<BuyerDeptEmployee> selectBuyerDeptEmployeeList(BuyerDeptEmployee buyerDeptEmployee);

    /**
     * 查询项目员工列表
     *
     * @param buyerDeptEmployee 企业信息员工
     * @return 企业信息员工集合
     */
    public List<BuyerDeptEmployee> selectBuyerDeptEmployeeLists(BuyerDeptEmployee buyerDeptEmployee);

    /**
     * 新增企业信息员工
     * 
     * @param buyerDeptEmployee 企业信息员工
     * @return 结果
     */
    public int insertBuyerDeptEmployee(BuyerDeptEmployee buyerDeptEmployee);

    /**
     * 修改企业信息员工
     * 
     * @param buyerDeptEmployee 企业信息员工
     * @return 结果
     */
    public int updateBuyerDeptEmployee(BuyerDeptEmployee buyerDeptEmployee);

    /**
     * 删除企业信息员工
     * 
     * @param id 企业信息员工主键
     * @return 结果
     */
    public int deleteBuyerDeptEmployeeById(String id);

    /**
     * 批量删除企业信息员工
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBuyerDeptEmployeeByIds(String[] ids);
}
